@@ -185,6 +185,7 @@ RULES = [
                 },
                 'created_at': "1983-06-16T00:00:00-00:00",
                 'last_used_at': "1983-06-16T00:00:00-00:00",
+                'description': "Some description",
                 'devices': {
                     'root': {
                         'path': "/",
@@ -212,7 +213,10 @@ RULES = [
                 ],
                 'stateful': False,
                 'status': "Running",
-                'status_code': 103
+                'status_code': 103,
+                'unsupportedbypylxd': "This attribute is not supported by "\
+                    "pylxd. We want to test whether the mere presence of it "\
+                    "makes it crash."
             }},
         'method': 'GET',
         'url': r'^http://pylxd.test/1.0/containers/an-container$',
